////// Fragment Shader
precision highp float;
varying highp vec2 textureCoordinate;
varying highp vec2 textureCoordinate2;
uniform sampler2D inputImageTexture;  // 纹理A
uniform sampler2D inputImageTexture2;  // 纹理B
uniform float progress;                // 过渡进度 (0.0 到 1.0)
uniform int type;                      // 过渡类型(0:亮度低的先出现，1:亮度高的先出现)

vec4 getFromColor(vec2 uv) {
    vec4 imageColor = texture2D(inputImageTexture, uv);
    return imageColor;
}

vec4 getToColor(vec2 uv) {
    vec4 imageColor = texture2D(inputImageTexture2, uv);
    return imageColor;
}
// 计算亮度值（Luminance），使用标准加权方式
float getLuminance(vec4 color) {
    return dot(color.rgb, vec3(0.299, 0.587, 0.114));
}



void main() {
    // 获取目标图层和参考图层的颜色
    vec4 colorA = getFromColor(textureCoordinate);
    vec4 colorB = getToColor(textureCoordinate);

    // 计算纹理B中该像素的亮度值
    float luminanceB = getLuminance(colorB);

    // 基于亮度值控制过渡，使用step来创建硬性过渡
    float transitionFactor;
    if (type == 1) {
        transitionFactor = step(luminanceB, progress);
    } else {
        transitionFactor = step(1.0 - progress, luminanceB);
    }
    // 使用 transitionFactor 在纹理A和纹理B之间进行插值
    vec4 finalColor = mix(colorA, colorB, transitionFactor);

    gl_FragColor = finalColor;
}